@@ -1,13 +1,12 @@
 import csv
 import logging
 from transformers import InputExample
-from ratsnlp.nlpbook.data_utils import Corpus
 
 
 logger = logging.getLogger(__name__)
 
 
-class KoreanChatCorpus(Corpus):
+class KoreanChatCorpus:
 
     @classmethod
     def _read_corpus(cls, input_file, quotechar='"'):
