@@ -2,7 +2,7 @@ from transformers import PreTrainedModel
 from transformers.optimization import AdamW
 from ratsnlp.nlpbook.metrics import accuracy
 from pytorch_lightning import LightningModule
-from ratsnlp.nlpbook.arguments import TrainArguments
+from ratsnlp.nlpbook.qa import QATrainArguments
 from pytorch_lightning.metrics.classification import accuracy
 from pytorch_lightning.trainer.supporters import TensorRunningAccum
 from torch.optim.lr_scheduler import ExponentialLR, CosineAnnealingWarmRestarts
@@ -12,7 +12,7 @@ class QATask(LightningModule):
 
     def __init__(self,
                  model: PreTrainedModel,
-                 args: TrainArguments,
+                 args: QATrainArguments,
     ):
         super().__init__()
         self.model = model
@@ -39,10 +39,12 @@ class QATask(LightningModule):
         return self.model(**kwargs)
 
     def step(self, inputs, mode="train"):
-        loss, logits = self.model(**inputs)
-        preds = logits.argmax(dim=-1)
-        labels = inputs["labels"]
-        acc = accuracy(preds, labels)
+        loss, start_logits, end_logits = self.model(**inputs)
+        start_preds = start_logits.argmax(dim=-1)
+        end_preds = end_logits.argmax(dim=-1)
+        start_positions = inputs["start_positions"]
+        end_positions = inputs["end_positions"]
+        acc = (accuracy(start_preds, start_positions) + accuracy(end_preds, end_positions)) / 2
         self.running_accuracy.append(acc)
         logs = {f"{mode}_loss": loss, f"{mode}_acc": acc}
         return {"loss": loss, "log": logs}
